@@ -198,7 +198,7 @@ extern int yydebug;
 typedef union YYSTYPE YYSTYPE;
 union YYSTYPE
 {
-#line 70 "../coda/libcoda/coda-expr-parser.y" /* yacc.c:1909  */
+#line 79 "../coda/libcoda/coda-expr-parser.y" /* yacc.c:1909  */
 
     char *stringval;
     struct coda_expression_struct *expr;
@@ -210,8 +210,7 @@ union YYSTYPE
 #endif
 
 
-extern YYSTYPE yylval;
 
-int yyparse (void);
+int yyparse (void *scanner);
 
 #endif /* !YY_YY_LIBCODA_CODA_EXPR_PARSER_H_INCLUDED  */
