@@ -129,7 +129,7 @@ enum
     num_sp3_types
 };
 
-static coda_type **sp3_type = NULL;
+static THREAD_LOCAL coda_type **sp3_type = NULL;
 
 typedef struct ingest_info_struct
 {
@@ -866,7 +866,7 @@ static int get_line(FILE *f, char *line)
         line[0] = '\0';
         return 0;
     }
-    length = strlen(line);
+    length = (long)strlen(line);
 
     /* remove 'linefeed' character if available */
     if (length > 0 && line[length - 1] == '\n')
