@@ -59,7 +59,7 @@ static void generate_escaped_string(const char *str, int length)
 
     if (length < 0)
     {
-        length = strlen(str);
+        length = (int)strlen(str);
     }
 
     while (i < length)
@@ -203,7 +203,7 @@ static int eval_expression(coda_cursor *cursor)
                                    coda_errno_to_string(coda_errno));
                     return -1;
                 }
-                printf("%g\n", value);
+                printf("%.16g\n", value);
             }
             break;
         case coda_expression_string:   /* string */
